@@ -139,20 +139,25 @@ class ACO():
 
         
 
-    def load_map(self,filepath ='res\\map.dll',reverse = False):
-        with open(filepath,'r') as f:
-            a_1 = f.readlines()
-        self.map_lenght = len(a_1)
-        for i in range(self.map_lenght):
-            a_1[i] = a_1[i].strip('\n')
-        for i in a_1:
-            l = []
-            for j in i:
-                if j == '0':
-                    l.append(0)
-                else:
-                    l.append(1)
-            self.map_data.append(l)
+    def load_map(self,filepath ='res\\map.dll',map_data = None,reverse = False):
+        self.has_load_map = True
+        if map_data == None:
+            with open(filepath,'r') as f:
+                a_1 = f.readlines()
+            self.map_lenght = len(a_1)
+            for i in range(self.map_lenght):
+                a_1[i] = a_1[i].strip('\n')
+            for i in a_1:
+                l = []
+                for j in i:
+                    if j == '0':
+                        l.append(0)
+                    else:
+                        l.append(1)
+                self.map_data.append(l)
+        else:
+            self.map_data = copy.deepcopy(map_data)
+            self.map_lenght = len(self.map_data)
         if reverse == True:
             self.map_data.reverse()
         self.init_pher(self.pher_init)  #初始化信息素浓度
